pub struct ConnectionProfile {Show 18 fields
pub bigquery_profile: Option<BigQueryProfile>,
pub create_time: Option<DateTime<Utc>>,
pub display_name: Option<String>,
pub forward_ssh_connectivity: Option<ForwardSshTunnelConnectivity>,
pub gcs_profile: Option<GcsProfile>,
pub labels: Option<HashMap<String, String>>,
pub mongodb_profile: Option<MongodbProfile>,
pub mysql_profile: Option<MysqlProfile>,
pub name: Option<String>,
pub oracle_profile: Option<OracleProfile>,
pub postgresql_profile: Option<PostgresqlProfile>,
pub private_connectivity: Option<PrivateConnectivity>,
pub salesforce_profile: Option<SalesforceProfile>,
pub satisfies_pzi: Option<bool>,
pub satisfies_pzs: Option<bool>,
pub sql_server_profile: Option<SqlServerProfile>,
pub static_service_ip_connectivity: Option<StaticServiceIpConnectivity>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A set of reusable connection configurations to be used as a source or destination for a stream.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations connection profiles create projects (request)
- locations connection profiles get projects (response)
- locations connection profiles patch projects (request)
Fields
bigquery_profile: Option<BigQueryProfile>BigQuery Connection Profile configuration.
create_time: Option<DateTime<Utc>>Output only. The create time of the resource.
display_name: Option<String>Required. Display name.
forward_ssh_connectivity: Option<ForwardSshTunnelConnectivity>Forward SSH tunnel connectivity.
gcs_profile: Option<GcsProfile>Cloud Storage ConnectionProfile configuration.
labels: Option<HashMap<String, String>>Labels.
mongodb_profile: Option<MongodbProfile>MongoDB Connection Profile configuration.
mysql_profile: Option<MysqlProfile>MySQL ConnectionProfile configuration.
name: Option<String>Output only. Identifier. The resource’s name.
oracle_profile: Option<OracleProfile>Oracle ConnectionProfile configuration.
postgresql_profile: Option<PostgresqlProfile>PostgreSQL Connection Profile configuration.
private_connectivity: Option<PrivateConnectivity>Private connectivity.
salesforce_profile: Option<SalesforceProfile>Salesforce Connection Profile configuration.
satisfies_pzi: Option<bool>Output only. Reserved for future use.
satisfies_pzs: Option<bool>Output only. Reserved for future use.
sql_server_profile: Option<SqlServerProfile>SQLServer Connection Profile configuration.
static_service_ip_connectivity: Option<StaticServiceIpConnectivity>Static Service IP connectivity.
update_time: Option<DateTime<Utc>>Output only. The update time of the resource.