MongodbProfile

Struct MongodbProfile 

pub struct MongodbProfile {
    pub additional_options: Option<HashMap<String, String>>,
    pub host_addresses: Option<Vec<HostAddress>>,
    pub password: Option<String>,
    pub replica_set: Option<String>,
    pub secret_manager_stored_password: Option<String>,
    pub srv_connection_format: Option<SrvConnectionFormat>,
    pub ssl_config: Option<MongodbSslConfig>,
    pub standard_connection_format: Option<StandardConnectionFormat>,
    pub username: Option<String>,
}
MongoDB profile.

This type is not used in any activity, and only used as part of another schema.

Fields

additional_options: Option<HashMap<String, String>>

Optional. Specifies additional options for the MongoDB connection. The options should be sent as key-value pairs, for example: additional_options = {"serverSelectionTimeoutMS": "10000", "directConnection": "true"}. Keys are case-sensitive and should match the official MongoDB connection string options: https://www.mongodb.com/docs/manual/reference/connection-string-options/ The server will not modify the values provided by the user.

host_addresses: Option<Vec<HostAddress>>

Required. List of host addresses for a MongoDB cluster. For SRV connection format, this list must contain exactly one DNS host without a port. For Standard connection format, this list must contain all the required hosts in the cluster with their respective ports.

password: Option<String>

Optional. Password for the MongoDB connection. Mutually exclusive with the secret_manager_stored_password field.

replica_set: Option<String>

Optional. Name of the replica set. Only needed for self hosted replica set type MongoDB cluster. For SRV connection format, this field must be empty. For Standard connection format, this field must be specified.

secret_manager_stored_password: Option<String>

Optional. A reference to a Secret Manager resource name storing the SQLServer connection password. Mutually exclusive with the password field.

srv_connection_format: Option<SrvConnectionFormat>

Srv connection format.

ssl_config: Option<MongodbSslConfig>

Optional. SSL configuration for the MongoDB connection.

standard_connection_format: Option<StandardConnectionFormat>

Standard connection format.

username: Option<String>

Required. Username for the MongoDB connection.