pub struct MongodbSslConfig {
pub ca_certificate: Option<String>,
pub ca_certificate_set: Option<bool>,
pub client_certificate: Option<String>,
pub client_certificate_set: Option<bool>,
pub client_key: Option<String>,
pub client_key_set: Option<bool>,
pub secret_manager_stored_client_key: Option<String>,
}Expand description
MongoDB SSL configuration information.
This type is not used in any activity, and only used as part of another schema.
Fields
ca_certificate: Option<String>Optional. Input only. PEM-encoded certificate of the CA that signed the source database server’s certificate.
ca_certificate_set: Option<bool>Output only. Indicates whether the ca_certificate field is set.
client_certificate: Option<String>Optional. Input only. PEM-encoded certificate that will be used by the replica to authenticate against the source database server. If this field is used then the ‘client_key’ and the ‘ca_certificate’ fields are mandatory.
client_certificate_set: Option<bool>Output only. Indicates whether the client_certificate field is set.
client_key: Option<String>Optional. Input only. PEM-encoded private key associated with the Client Certificate. If this field is used then the ‘client_certificate’ and the ‘ca_certificate’ fields are mandatory.
client_key_set: Option<bool>Output only. Indicates whether the client_key field is set.
secret_manager_stored_client_key: Option<String>Optional. Input only. A reference to a Secret Manager resource name storing the PEM-encoded private key associated with the Client Certificate. If this field is used then the ‘client_certificate’ and the ‘ca_certificate’ fields are mandatory. Mutually exclusive with the client_key field.