pub struct MysqlProfile {
pub hostname: Option<String>,
pub password: Option<String>,
pub port: Option<i32>,
pub secret_manager_stored_password: Option<String>,
pub ssl_config: Option<MysqlSslConfig>,
pub username: Option<String>,
}Expand description
MySQL database profile.
This type is not used in any activity, and only used as part of another schema.
Fields
hostname: Option<String>Required. Hostname for the MySQL connection.
password: Option<String>Optional. Input only. Password for the MySQL connection. Mutually exclusive with the secret_manager_stored_password field.
port: Option<i32>Port for the MySQL connection, default value is 3306.
secret_manager_stored_password: Option<String>Optional. A reference to a Secret Manager resource name storing the MySQL connection password. Mutually exclusive with the password field.
ssl_config: Option<MysqlSslConfig>SSL configuration for the MySQL connection.
username: Option<String>Required. Username for the MySQL connection.