pub struct OracleProfile {
pub connection_attributes: Option<HashMap<String, String>>,
pub database_service: Option<String>,
pub hostname: Option<String>,
pub oracle_asm_config: Option<OracleAsmConfig>,
pub oracle_ssl_config: Option<OracleSslConfig>,
pub password: Option<String>,
pub port: Option<i32>,
pub secret_manager_stored_password: Option<String>,
pub username: Option<String>,
}Expand description
Oracle database profile.
This type is not used in any activity, and only used as part of another schema.
Fields
connection_attributes: Option<HashMap<String, String>>Connection string attributes
database_service: Option<String>Required. Database for the Oracle connection.
hostname: Option<String>Required. Hostname for the Oracle connection.
oracle_asm_config: Option<OracleAsmConfig>Optional. Configuration for Oracle ASM connection.
oracle_ssl_config: Option<OracleSslConfig>Optional. SSL configuration for the Oracle connection.
password: Option<String>Optional. Password for the Oracle connection. Mutually exclusive with the secret_manager_stored_password field.
port: Option<i32>Port for the Oracle connection, default value is 1521.
secret_manager_stored_password: Option<String>Optional. A reference to a Secret Manager resource name storing the Oracle connection password. Mutually exclusive with the password field.
username: Option<String>Required. Username for the Oracle connection.