pub struct SqlServerProfile {
pub database: Option<String>,
pub hostname: Option<String>,
pub password: Option<String>,
pub port: Option<i32>,
pub secret_manager_stored_password: Option<String>,
pub ssl_config: Option<SqlServerSslConfig>,
pub username: Option<String>,
}Expand description
SQLServer database profile.
This type is not used in any activity, and only used as part of another schema.
Fields
database: Option<String>Required. Database for the SQLServer connection.
hostname: Option<String>Required. Hostname for the SQLServer connection.
password: Option<String>Optional. Password for the SQLServer connection. Mutually exclusive with the secret_manager_stored_password field.
port: Option<i32>Port for the SQLServer connection, default value is 1433.
secret_manager_stored_password: Option<String>Optional. A reference to a Secret Manager resource name storing the SQLServer connection password. Mutually exclusive with the password field.
ssl_config: Option<SqlServerSslConfig>Optional. SSL configuration for the SQLServer connection.
username: Option<String>Required. Username for the SQLServer connection.