pub struct StreamObject {
pub backfill_job: Option<BackfillJob>,
pub create_time: Option<DateTime<Utc>>,
pub customization_rules: Option<Vec<CustomizationRule>>,
pub display_name: Option<String>,
pub errors: Option<Vec<Error>>,
pub name: Option<String>,
pub source_object: Option<SourceObjectIdentifier>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A specific stream object (e.g a specific DB table).
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations streams objects get projects (response)
- locations streams objects lookup projects (response)
Fields
backfill_job: Option<BackfillJob>The latest backfill job that was initiated for the stream object.
create_time: Option<DateTime<Utc>>Output only. The creation time of the object.
customization_rules: Option<Vec<CustomizationRule>>Output only. The customization rules for the object. These rules are derived from the parent Stream’s rule_sets and represent the intended configuration for the object.
display_name: Option<String>Required. Display name.
errors: Option<Vec<Error>>Output only. Active errors on the object.
name: Option<String>Output only. Identifier. The object resource’s name.
source_object: Option<SourceObjectIdentifier>The object identifier in the data source.
update_time: Option<DateTime<Utc>>Output only. The last update time of the object.